@@ -11,7 +11,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   File::RsyncP is Copyright (C) 2002-2010  Craig Barratt.
+#   File::RsyncP is Copyright (C) 2002-2015  Craig Barratt.
 #
 #   Rsync is Copyright (C) 1996-2001 by Andrew Tridgell, 1996 by Paul
 #   Mackerras, 2001-2002 by Martin Pool, and 2003-2009 by Wayne Davison,
@@ -33,7 +33,7 @@
 #
 #========================================================================
 #
-# Version 0.70, released 25 Jul 2010.
+# Version 0.72, released 11 Jan 2015.
 #
 # See http://perlrsync.sourceforge.net.
 #
@@ -53,7 +53,7 @@ use Encode qw/from_to/;
 use Fcntl;
 
 use vars qw($VERSION);
-$VERSION = '0.70';
+$VERSION = '0.72';
 
 use constant S_IFMT       => 0170000;	# type of file
 use constant S_IFDIR      => 0040000; 	# directory
@@ -469,8 +469,9 @@ sub go
         #
 
         #
-        # Skip a word: this is the io_error flag.
+        # Read and skip a word: this is the io_error flag.
         #
+        return "can't read io_error flag" if ( $rs->getChunk(4) < 0 );
 	$rs->{chunkData} = substr($rs->{chunkData}, 4);
 
 	#
